@@ -23,7 +23,7 @@ def cache_data(key, value, expiration_seconds=None):
     return value
 
 
-def get_cached_data(key, collection=None):
+def get_cached_data(key):
     import json
     client = create_cache_client()
 
@@ -33,7 +33,7 @@ def get_cached_data(key, collection=None):
     return value
 
 
-def delete_cached_keys(keys, collection=None):
+def delete_cached_keys(keys):
     client = create_cache_client()
     cache_keys = [key for key in keys]
     client.delete(*cache_keys)
