@@ -60,6 +60,19 @@ def compose_integration_logs(job_uuid, segments, file_pattern, time, id_types, o
     return rows
 
 
+def get_delivery_error_type(exception):
+    from exceptions import AuthenticationError, ConfigurationError, NotFoundError
+    if isinstance(exception, AuthenticationError):
+        error_type = 'Authentication Error'
+    elif isinstance(exception, ConfigurationError):
+        error_type = 'Configuration Error'
+    elif isinstance(exception, NotFoundError):
+        error_type = 'Not Found Error'
+    else:
+        error_type = 'Delivery Failure'
+    return error_type
+
+
 def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination, file_headers, segments, id_types,
                  operations, chunk_start_number, start_time=None, **kwargs):
     from stratus_api.integrations import get_integration_settings
@@ -87,6 +100,7 @@ def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination
     ):
         chunk_start = datetime.utcnow()
         tb = None
+        error_type = None
         try:
             success = distribution_retry_wrapper(
                 destination=destination, platform_name=platform_name, segments=segment_mapping, local_path=local_path,
@@ -96,6 +110,7 @@ def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination
             import traceback
             tb = traceback.format_exc()
             success = False
+            error_type = get_delivery_error_type(exception=e)
             if get_settings()['environment'] not in {'qa', 'prod'}:
                 raise e
         if success:
@@ -107,7 +122,8 @@ def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination
                     segment_uuid=segment_uuid
                 )
         log_chunk_delivery(success=success, start=chunk_start, chunk_number=chunk_number, destination=destination,
-                           segments=segment_mapping, job_uuid=job_uuid, platform_name=platform_name, traceback=tb)
+                           segments=segment_mapping, job_uuid=job_uuid, platform_name=platform_name, traceback=tb,
+                           error_type=error_type)
 
     end_time = datetime.utcnow()
 
